@@ -44,7 +44,9 @@ def _fixture_setup(self):
 
 
 def test_runner(self):
-    """smoke test"""
+    """
+    smoke test
+    """
 
     # авторизуем пользователя
     if (hasattr(settings, 'SMOKNUR_USERNAME') 
